parse

Function parse 

pub fn parse(input: &[u8]) -> Result<Vdf<'_>>
Parse binary VDF data (autodetects format).

Attempts to parse as appinfo.vdf first, then falls back to shortcuts.vdf format. For shortcuts format, returns zero-copy data borrowed from input. For appinfo format, returns mixed data: root key and app ID keys are owned, but actual parsed values (including string table entries) are borrowed. For packageinfo format, returns mixed data similar to appinfo.

Uses default ParseOptions (lossy handling of invalid UTF-8). Use parse_with to override.